pub trait Exists<T: Sized> {
// Required method
fn erase(self) -> Erased<T>;
}Expand description
The Exists trait is intended to be used with impl, to denote
an argument where the existence of a value is sufficient as an argument
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".