Trait singleton_trait::Exists[][src]

pub trait Exists<T>: Into<Erased<T>> { }
The Exists trait is intended to be used with impl, to denote an argument where the existence of a value is sufficient as an argument

Implementors