Trait Exists
Other items insingleton_trait
pub trait Exists<T>: Into<Erased<T>> { }
The Exists trait is intended to be used with impl, to denote an argument where the existence of a value is sufficient as an argument
impl
impl<T: Into<Erased<T>>> Exists<T> for T